pub struct Button { /* private fields */ }Expand description
One button inside a Keyboard.
Implementations
Sourceimpl Button
impl Button
Sourcepub fn callback(label: impl Into<String>, id: impl Into<String>) -> Self
pub fn callback(label: impl Into<String>, id: impl Into<String>) -> Self
Callback button. id is what comes back when the user presses it.
Sourcepub fn url(label: impl Into<String>, url: impl Into<String>) -> Self
pub fn url(label: impl Into<String>, url: impl Into<String>) -> Self
Link button. The user’s client opens the URL when pressed.
Sourcepub fn callback_id(&self) -> Option<&str>
pub fn callback_id(&self) -> Option<&str>
The callback id, if this is a callback button.
Sourcepub fn url_target(&self) -> Option<&str>
pub fn url_target(&self) -> Option<&str>
The target url, if this is a url button.